@@ -6,7 +6,7 @@ from glue.viewers.common.tool import CheckableTool
 
 from jdaviz.core.events import SliceSelectWavelengthMessage, SliceToolStateMessage
 
-__all__ = []
+__all__ = ['SelectSlice']
 
 ICON_DIR = os.path.join(os.path.dirname(__file__), '..', '..', '..', 'data', 'icons')
 
@@ -24,8 +24,7 @@ class SelectSlice(CheckableTool):
 
     def activate(self):
         self.viewer.add_event_callback(self.on_mouse_event,
-                                       events=['dragstart', 'dragmove',
-                                               'dragend', 'dblclick'])
+                                       events=['dragmove', 'click'])
         msg = SliceToolStateMessage({'active': True}, sender=self)
         self.viewer.session.hub.broadcast(msg)
 
