@@ -73,6 +73,12 @@ def test_redshift(specviz_helper, spectrum1d):
                                    'obs_new': 5508})
     assert_allclose(line['obs'], 5508)
 
+    # https://github.com/spacetelescope/jdaviz/issues/1168
+    ll_plugin.vue_set_identify(('Test List', line, 0))
+    ll_plugin.vue_remove_list('Test List')
+    assert ll_plugin._viewer.spectral_lines is None
+    assert ll_plugin.identify_label == ''
+
 
 def test_line_identify(specviz_helper, spectrum1d):
     label = "Test 1D Spectrum"
