@@ -1,18 +1,23 @@
 from datetime import datetime
 
+import bqplot
 import numpy as np
 from astropy import units as u
 from astropy.table import QTable
 from astropy.time import Time
-from bqplot import pyplot as bqplt
 from ipywidgets import widget_serialization
-from photutils.aperture import ApertureStats
+from photutils.aperture import (ApertureStats, CircularAperture, EllipticalAperture,
+                                RectangularAperture)
+from regions import (CircleAnnulusPixelRegion, CirclePixelRegion, EllipsePixelRegion,
+                     RectanglePixelRegion)
 from traitlets import Any, Bool, List, Unicode, observe
 
+from jdaviz.core.custom_traitlets import FloatHandleEmpty
 from jdaviz.core.events import SnackbarMessage
 from jdaviz.core.region_translators import regions2aperture
 from jdaviz.core.registries import tray_registry
 from jdaviz.core.template_mixin import TemplateMixin, DatasetSelectMixin, SubsetSelect
+from jdaviz.utils import bqplot_clear_figure, PRIHDR_KEY
 
 __all__ = ['SimpleAperturePhotometry']
 
@@ -25,6 +30,8 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
     bg_subset_items = List().tag(sync=True)
     bg_subset_selected = Unicode("").tag(sync=True)
     background_value = Any(0).tag(sync=True)
+    bg_annulus_inner_r = FloatHandleEmpty(0).tag(sync=True)
+    bg_annulus_width = FloatHandleEmpty(10).tag(sync=True)
     pixel_area = Any(0).tag(sync=True)
     counts_factor = Any(0).tag(sync=True)
     flux_scaling = Any(0).tag(sync=True)
@@ -48,11 +55,13 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
                                       'bg_subset_items',
                                       'bg_subset_selected',
                                       default_text='Manual',
+                                      manual_options=['Manual', 'Annulus'],
                                       allowed_type='spatial')
 
         self._selected_data = None
         self._selected_subset = None
-        self.plot_types = ["Radial Profile", "Radial Profile (Raw)"]
+        self._fig = bqplot.Figure()
+        self.plot_types = ["Curve of Growth", "Radial Profile", "Radial Profile (Raw)"]
         self.current_plot_type = self.plot_types[0]
 
     def reset_results(self):
@@ -60,7 +69,7 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
         self.results = []
         self.plot_available = False
         self.radial_plot = ''
-        bqplt.clear()
+        bqplot_clear_figure(self._fig)
 
     @observe('dataset_selected')
     def _dataset_selected_changed(self, event={}):
@@ -74,7 +83,10 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
             self.flux_scaling = 0
 
             # Extract telescope specific unit conversion factors, if applicable.
-            meta = self._selected_data.meta
+            meta = self._selected_data.meta.copy()
+            if PRIHDR_KEY in meta:
+                meta.update(meta[PRIHDR_KEY])
+                del meta[PRIHDR_KEY]
             if 'telescope' in meta:
                 telescope = meta['telescope']
             else:
@@ -108,11 +120,10 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
                 f"Failed to extract {self.dataset_selected}: {repr(e)}",
                 color='error', sender=self))
 
-        # Auto-populate background, if applicable
-        self._bg_subset_selected_changed()
-
-        # update self._selected_subset with the new self._selected_data
+        # Update self._selected_subset with the new self._selected_data
+        # and auto-populate background, if applicable.
         self._subset_selected_changed()
+        self._bg_subset_selected_changed()
 
     def _get_region_from_subset(self, subset):
         for subset_grp in self.app.data_collection.subset_groups:
@@ -135,31 +146,63 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
         try:
             self._selected_subset = self._get_region_from_subset(subset_selected)
             self._selected_subset.meta['label'] = subset_selected
+
+            if isinstance(self._selected_subset, CirclePixelRegion):
+                self.bg_annulus_inner_r = self._selected_subset.radius
+            elif isinstance(self._selected_subset, EllipsePixelRegion):
+                self.bg_annulus_inner_r = max(self._selected_subset.width,
+                                              self._selected_subset.height) * 0.5
+            elif isinstance(self._selected_subset, RectanglePixelRegion):
+                self.bg_annulus_inner_r = np.sqrt(self._selected_subset.width ** 2 +
+                                                  self._selected_subset.height ** 2) * 0.5
+            else:  # pragma: no cover
+                raise TypeError(f'Unsupported region shape: {self._selected_subset.__class__}')
+
         except Exception as e:
             self._selected_subset = None
             self.reset_results()
             self.hub.broadcast(SnackbarMessage(
                 f"Failed to extract {subset_selected}: {repr(e)}", color='error', sender=self))
 
+    def _calc_bg_subset_median(self, reg):
+        # Basically same way image stats are calculated in vue_do_aper_phot()
+        # except here we only care about one stat for the background.
+        data = self._selected_data
+        comp = data.get_component(data.main_components[0])
+        aper_mask_stat = reg.to_mask(mode='center')
+        img_stat = aper_mask_stat.get_values(comp.data, mask=None)
+
+        # photutils/background/_utils.py --> nanmedian()
+        return np.nanmedian(img_stat)  # Naturally in data unit
+
+    @observe('bg_annulus_inner_r', 'bg_annulus_width')
+    def _bg_annulus_updated(self, *args):
+        if self.bg_subset_selected != 'Annulus':
+            return
+
+        try:
+            inner_r = float(self.bg_annulus_inner_r)
+            reg = CircleAnnulusPixelRegion(
+                self._selected_subset.center, inner_radius=inner_r,
+                outer_radius=inner_r + float(self.bg_annulus_width))
+            self.background_value = self._calc_bg_subset_median(reg)
+
+        except Exception:  # Error snackbar suppressed to prevent excessive queue.
+            self.background_value = 0
+
     @observe('bg_subset_selected')
     def _bg_subset_selected_changed(self, event={}):
         bg_subset_selected = event.get('new', self.bg_subset_selected)
         if bg_subset_selected == 'Manual':
             # we'll later access the user's self.background_value directly
             return
+        if bg_subset_selected == 'Annulus':
+            self._bg_annulus_updated()
+            return
 
         try:
-            # Basically same way image stats are calculated in vue_do_aper_phot()
-            # except here we only care about one stat for the background.
-            data = self._selected_data
             reg = self._get_region_from_subset(bg_subset_selected)
-            comp = data.get_component(data.main_components[0])
-            aper_mask_stat = reg.to_mask(mode='center')
-            img_stat = aper_mask_stat.get_values(comp.data, mask=None)
-
-            # photutils/background/_utils.py --> nanmedian()
-            self.background_value = np.nanmedian(img_stat)  # Naturally in data unit
-
+            self.background_value = self._calc_bg_subset_median(reg)
         except Exception as e:
             self.background_value = 0
             self.hub.broadcast(SnackbarMessage(
@@ -220,11 +263,11 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
             phot_table['xcentroid'].unit = u.pix  # photutils only assumes, we make it real
             phot_table['ycentroid'].unit = u.pix
             rawsum = phot_table['sum'][0]
-            npix = phot_table['sum_aper_area'][0]
 
             if include_pixarea_fac:
                 pixarea = pixarea * (u.arcsec * u.arcsec / (u.pix * u.pix))
-                pixarea_fac = npix * pixarea.to(u.sr / (u.pix * u.pix))
+                # NOTE: Sum already has npix value encoded, so we simply apply the npix unit here.
+                pixarea_fac = (u.pix * u.pix) * pixarea.to(u.sr / (u.pix * u.pix))
                 phot_table['sum'] = [rawsum * pixarea_fac]
             else:
                 pixarea_fac = None
@@ -266,36 +309,48 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
                     phot_table['id'][0] = 1
                     self.app._aper_phot_results = phot_table
 
-            # Radial profile (Raw)
-            reg_bb = phot_aperstats.bbox
-            reg_ogrid = np.ogrid[reg_bb.iymin:reg_bb.iymax, reg_bb.ixmin:reg_bb.ixmax]
-            radial_dx = reg_ogrid[1] - aperture.positions[0]
-            radial_dy = reg_ogrid[0] - aperture.positions[1]
-            radial_r = np.hypot(radial_dx, radial_dy).ravel()  # pix
-            radial_img = phot_aperstats.data_cutout.data.ravel()  # data unit
-
-            # Radial profile
-            if self.current_plot_type == "Radial Profile":
-                # This algorithm is from the imexam package,
-                # see licenses/IMEXAM_LICENSE.txt for more details
-                radial_r = list(radial_r)
-                y_data = np.bincount(radial_r, radial_img) / np.bincount(radial_r)
-                radial_r = np.arange(y_data.size)
-                markerstyle = '--o'
-                bqplot_kw = {'marker_size': 32}
-            else:
-                y_data = radial_img
-                markerstyle = 'o'
-                bqplot_kw = {'default_size': 1}
-
-            bqplt.clear()
+            # Plots.
+            # TODO: Jenn wants title at bottom.
+            bqplot_clear_figure(self._fig)
+            self._fig.title_style = {'font-size': '12px'}
             # NOTE: default margin in bqplot is 60 in all directions
-            fig = bqplt.figure(1, title='Radial profile from Subset center',
-                               fig_margin={'top': 60, 'bottom': 60, 'left': 40, 'right': 10},
-                               title_style={'font-size': '12px'})  # TODO: Jenn wants title at bottom. # noqa
-            bqplt.plot(radial_r, y_data, markerstyle, figure=fig, colors='gray', **bqplot_kw)
-            bqplt.xlabel(label='pix', mark=fig.marks[-1], figure=fig)
-            bqplt.ylabel(label=comp.units or 'Value', mark=fig.marks[-1], figure=fig)
+            self._fig.fig_margin = {'top': 60, 'bottom': 60, 'left': 40, 'right': 10}
+            line_x_sc = bqplot.LinearScale()
+            line_y_sc = bqplot.LinearScale()
+
+            if self.current_plot_type == "Curve of Growth":
+                self._fig.title = 'Curve of growth from Subset center'
+                x_arr, sum_arr, x_label, y_label = _curve_of_growth(
+                    comp_data, aperture, phot_table['sum'][0], wcs=data.coords,
+                    background=bg, pixarea_fac=pixarea_fac)
+                self._fig.axes = [bqplot.Axis(scale=line_x_sc, label=x_label),
+                                  bqplot.Axis(scale=line_y_sc, orientation='vertical',
+                                              label=y_label)]
+                bqplot_line = bqplot.Lines(x=x_arr, y=sum_arr, marker='circle',
+                                           scales={'x': line_x_sc, 'y': line_y_sc},
+                                           marker_size=32, colors='gray')
+
+            else:  # Radial profile
+                self._fig.axes = [bqplot.Axis(scale=line_x_sc, label='pix'),
+                                  bqplot.Axis(scale=line_y_sc, orientation='vertical',
+                                              label=comp.units or 'Value')]
+
+                if self.current_plot_type == "Radial Profile":
+                    self._fig.title = 'Radial profile from Subset center'
+                    x_data, y_data = _radial_profile(
+                        phot_aperstats.data_cutout, phot_aperstats.bbox, aperture, raw=False)
+                    bqplot_line = bqplot.Lines(x=x_data, y=y_data, marker='circle',
+                                               scales={'x': line_x_sc, 'y': line_y_sc},
+                                               marker_size=32, colors='gray')
+                else:  # Radial Profile (Raw)
+                    self._fig.title = 'Raw radial profile from Subset center'
+                    radial_r, radial_img = _radial_profile(
+                        phot_aperstats.data_cutout, phot_aperstats.bbox, aperture, raw=True)
+                    bqplot_line = bqplot.Scatter(x=radial_r, y=radial_img, marker='circle',
+                                                 scales={'x': line_x_sc, 'y': line_y_sc},
+                                                 default_size=1, colors='gray')
+
+            self._fig.marks = [bqplot_line]
 
         except Exception as e:  # pragma: no cover
             self.reset_results()
@@ -326,6 +381,134 @@ class SimpleAperturePhotometry(TemplateMixin, DatasetSelectMixin):
                     tmp.append({'function': key, 'result': str(x)})
             self.results = tmp
             self.result_available = True
-            self.radial_plot = fig
-            self.bqplot_figs_resize = [fig]
+            self.radial_plot = self._fig
+            self.bqplot_figs_resize = [self._fig]
             self.plot_available = True
+
+
+# NOTE: These are hidden because the APIs are for internal use only
+# but we need them as a separate functions for unit testing.
+
+def _radial_profile(radial_cutout, reg_bb, aperture, raw=False):
+    """Calculate radial profile.
+
+    Parameters
+    ----------
+    radial_cutout : ndarray
+        Cutout image from ``ApertureStats``.
+
+    reg_bb : obj
+        Bounding box from ``ApertureStats``.
+
+    aperture : obj
+        ``photutils`` aperture object.
+
+    raw : bool
+        If `True`, returns raw data points for scatter plot.
+        Otherwise, use ``imexam`` algorithm for a clean plot.
+
+    """
+    reg_ogrid = np.ogrid[reg_bb.iymin:reg_bb.iymax, reg_bb.ixmin:reg_bb.ixmax]
+    radial_dx = reg_ogrid[1] - aperture.positions[0]
+    radial_dy = reg_ogrid[0] - aperture.positions[1]
+    radial_r = np.hypot(radial_dx, radial_dy)[~radial_cutout.mask].ravel()  # pix
+    radial_img = radial_cutout.compressed()  # data unit
+
+    if raw:
+        x_arr = radial_r
+        y_arr = radial_img
+    else:
+        # This algorithm is from the imexam package,
+        # see licenses/IMEXAM_LICENSE.txt for more details
+        radial_r = list(radial_r)
+        y_arr = np.bincount(radial_r, radial_img) / np.bincount(radial_r)
+        x_arr = np.arange(y_arr.size)
+
+    return x_arr, y_arr
+
+
+def _curve_of_growth(data, aperture, final_sum, wcs=None, background=0, n_datapoints=10,
+                     pixarea_fac=None):
+    """Calculate curve of growth for aperture photometry.
+
+    Parameters
+    ----------
+    data : ndarray or `~astropy.units.Quantity`
+        Data for the calculation.
+
+    aperture : obj
+        ``photutils`` aperture object.
+
+    final_sum : float or `~astropy.units.Quantity`
+        Aperture sum that is already calculated in the
+        main plugin above.
+
+    wcs : obj or `None`
+        Supported WCS objects or `None`.
+
+    background : float or `~astropy.units.Quantity`
+        Background to subtract, if any. Unit must match ``data``.
+
+    n_datapoints : int
+        Number of data points in the curve.
+
+    pixarea_fac : float or `None`
+        For ``flux_unit/sr`` to ``flux_unit`` conversion.
+
+    Returns
+    -------
+    x_arr : ndarray
+        Data for X-axis of the curve.
+
+    sum_arr : ndarray or `~astropy.units.Quantity`
+        Data for Y-axis of the curve.
+
+    x_label, y_label : str
+        X- and Y-axis labels, respectively.
+
+    Raises
+    ------
+    TypeError
+        Unsupported aperture.
+
+    """
+    n_datapoints += 1  # n + 1
+
+    if isinstance(aperture, CircularAperture):
+        x_label = 'Radius (pix)'
+        x_arr = np.linspace(0, aperture.r, num=n_datapoints)[1:]
+        aper_list = [CircularAperture(aperture.positions, cur_r) for cur_r in x_arr[:-1]]
+    elif isinstance(aperture, EllipticalAperture):
+        x_label = 'Semimajor axis (pix)'
+        x_arr = np.linspace(0, aperture.a, num=n_datapoints)[1:]
+        a_arr = x_arr[:-1]
+        b_arr = aperture.b * a_arr / aperture.a
+        aper_list = [EllipticalAperture(aperture.positions, cur_a, cur_b, theta=aperture.theta)
+                     for (cur_a, cur_b) in zip(a_arr, b_arr)]
+    elif isinstance(aperture, RectangularAperture):
+        x_label = 'Width (pix)'
+        x_arr = np.linspace(0, aperture.w, num=n_datapoints)[1:]
+        w_arr = x_arr[:-1]
+        h_arr = aperture.h * w_arr / aperture.w
+        aper_list = [RectangularAperture(aperture.positions, cur_w, cur_h, theta=aperture.theta)
+                     for (cur_w, cur_h) in zip(w_arr, h_arr)]
+    else:
+        raise TypeError(f'Unsupported aperture: {aperture}')
+
+    sum_arr = [ApertureStats(data, cur_aper, wcs=wcs, local_bkg=background).sum
+               for cur_aper in aper_list]
+    if isinstance(sum_arr[0], u.Quantity):
+        sum_arr = u.Quantity(sum_arr)
+    else:
+        sum_arr = np.array(sum_arr)
+    if pixarea_fac is not None:
+        sum_arr = sum_arr * pixarea_fac
+    sum_arr = np.append(sum_arr, final_sum)
+
+    if isinstance(sum_arr, u.Quantity):
+        y_label = sum_arr.unit.to_string()
+        sum_arr = sum_arr.value  # bqplot does not like Quantity
+    else:
+        y_label = 'Value'
+
+    return x_arr, sum_arr, x_label, y_label
