@@ -1,12 +1,11 @@
 from astropy import units as u
 from astropy.nddata import VarianceUncertainty, StdDevUncertainty, InverseVariance
 from glue.core.message import SubsetCreateMessage, SubsetDeleteMessage
-from specutils import Spectrum1D
-from traitlets import List, Unicode, Any
+from traitlets import List, Unicode, Any, observe
 
-from jdaviz.core.events import SnackbarMessage, RemoveDataMessage, AddDataMessage, RedshiftMessage
+from jdaviz.core.events import SnackbarMessage, RedshiftMessage
 from jdaviz.core.registries import tray_registry
-from jdaviz.core.template_mixin import PluginTemplateMixin
+from jdaviz.core.template_mixin import PluginTemplateMixin, DatasetSelectMixin
 from jdaviz.core.validunits import (create_spectral_equivalencies_list,
                                     create_flux_equivalencies_list)
 from jdaviz.configs.specviz.helper import _apply_redshift_to_spectra
@@ -19,13 +18,10 @@ unit_exponents = {StdDevUncertainty: 1,
 
 
 @tray_registry('g-unit-conversion', label="Unit Conversion")
-class UnitConversion(PluginTemplateMixin):
+class UnitConversion(PluginTemplateMixin, DatasetSelectMixin):
 
     template_file = __file__, "unit_conversion.vue"
 
-    dc_items = List([]).tag(sync=True)
-    selected_data = Unicode().tag(sync=True)
-
     current_flux_unit = Unicode().tag(sync=True)
     current_spectral_axis_unit = Unicode().tag(sync=True)
     new_flux_unit = Any().tag(sync=True)
@@ -37,61 +33,18 @@ class UnitConversion(PluginTemplateMixin):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self._viewer_data = None
-
-        self.spectrum = None
-
-        self.hub.subscribe(self, AddDataMessage, handler=self._on_viewer_data_changed)
-        self.hub.subscribe(self, RemoveDataMessage, handler=self._on_viewer_data_changed)
         self.hub.subscribe(self, SubsetCreateMessage, handler=self._on_viewer_subset_changed)
         self.hub.subscribe(self, SubsetDeleteMessage, handler=self._on_viewer_subset_changed)
 
         self._redshift = None
         self.app.hub.subscribe(self, RedshiftMessage, handler=self._redshift_listener)
 
-    def _on_viewer_data_changed(self, msg=None):
-        """
-        Callback method for when data is added or removed from a viewer, or
-        when a subset is created, deleted, or updated. This method receives
-        a glue message containing viewer information in the case of the former
-        set of events, and updates the available data list displayed to the
-        user.
-
-        Notes
-        -----
-        We do not attempt to parse any data at this point, at it can cause
-        visible lag in the application.
-
-        Parameters
-        ----------
-        msg : `glue.core.Message`
-            The glue message passed to this callback method.
-        """
-        self._viewer_id = self.app._viewer_item_by_reference(
-            'spectrum-viewer').get('id')
-
-        # Subsets are global and are not linked to specific viewer instances,
-        # so it's not required that we match any specific ids for that case.
-        # However, if the msg is not none, check to make sure that it's the
-        # viewer we care about.
-        if msg is not None and msg.viewer_id != self._viewer_id:
-            return
-
-        self._viewer_data = self.app.get_data_from_viewer('spectrum-viewer',
-                                                          include_subsets=False)
-
-        self.dc_items = [data.label
-                         for data in self.app.data_collection
-                         if data is not None]
-
-        if self.app.get_viewer("spectrum-viewer").state.reference_data is not None:
-
-            data_label = self.app.get_viewer("spectrum-viewer").state.reference_data.label
-            spectrum = self._viewer_data[data_label]
-
-            self.set_spectrum(spectrum, data_label)
-
-        self.update_ui()
+        # when accessing the selected data, access the spectrum-viewer version
+        # TODO: we'll probably want to update unit-conversion to be able to act on cubes directly
+        # in the future
+        self.dataset._viewers = ['spectrum-viewer']
+        # require entries to be in spectrum-viewer (not other cubeviz images, etc)
+        self.dataset.add_filter('layer_in_spectrum_viewer')
 
     def _on_viewer_subset_changed(self, *args):
         if len(self.app.data_collection.subset_groups) == 0:
@@ -104,43 +57,22 @@ class UnitConversion(PluginTemplateMixin):
         if msg.param == "redshift":
             self._redshift = msg.value
 
-    def set_spectrum(self, spectrum, label):
-        """
-        Set spectrum for unit conversion.
-
-        Parameters
-        ----------
-        spectrum : `~specutils.Spectrum1D`
-            Spectrum for unit conversion.
-        label : str
-            Label used to represent spectrum.
-        """
-        self.spectrum = spectrum
-        self.selected_data = label
-
-    def vue_data_selected(self, event):
-
-        self.set_spectrum(self.app.data_collection[event].get_object(cls=Spectrum1D), event)
-
-        self.update_ui()
-
-    def update_ui(self):
+    @observe('dataset_selected')
+    def update_ui(self, event=None):
         """
         Set up UI to have all values of currently visible spectra.
         """
-        if len(self._viewer_data) < 1:
-            self.selected_data = ""
-            self.current_flux_unit = ""
-            self.current_spectral_axis_unit = ""
+        spectrum = self.dataset.selected_obj
+        if spectrum is None:
             return
 
         # Set UI label to show current flux and spectral axis units.
-        self.current_flux_unit = self.spectrum.flux.unit.to_string()
-        self.current_spectral_axis_unit = self.spectrum.spectral_axis.unit.to_string()
+        self.current_flux_unit = spectrum.flux.unit.to_string()
+        self.current_spectral_axis_unit = spectrum.spectral_axis.unit.to_string()
 
         # Populate drop down with all valid options for unit conversion.
-        self.spectral_axis_unit_equivalencies = create_spectral_equivalencies_list(self.spectrum)
-        self.flux_unit_equivalencies = create_flux_equivalencies_list(self.spectrum)
+        self.spectral_axis_unit_equivalencies = create_spectral_equivalencies_list(spectrum)
+        self.flux_unit_equivalencies = create_flux_equivalencies_list(spectrum)
 
     def vue_unit_conversion(self, *args, **kwargs):
         """
@@ -149,9 +81,9 @@ class UnitConversion(PluginTemplateMixin):
         """
         if self._redshift is not None:
             # apply the global redshift to the new spectrum
-            spectrum = _apply_redshift_to_spectra(self.spectrum, self._redshift)
+            spectrum = _apply_redshift_to_spectra(self.dataset.selected_obj, self._redshift)
         else:
-            spectrum = self.spectrum
+            spectrum = self.dataset.selected_obj
 
         converted_spec = self.process_unit_conversion(spectrum,
                                                       self.new_flux_unit,
@@ -162,9 +94,9 @@ class UnitConversion(PluginTemplateMixin):
         new_label = ""
 
         # Finds the '_units_copy_' spectrum and does unit conversions in that copy.
-        if "_units_copy_" in self.selected_data:
+        if "_units_copy_" in self.dataset_selected:
 
-            selected_data_label = self.selected_data
+            selected_data_label = self.dataset_selected
             selected_data_label_split = selected_data_label.split("_units_copy_")
 
             new_label = selected_data_label_split[0] + label
@@ -199,7 +131,7 @@ class UnitConversion(PluginTemplateMixin):
                 self.app.add_data_to_viewer("spectrum-viewer", new_label, clear_other_data=True)
 
         else:
-            new_label = self.selected_data + label
+            new_label = self.dataset_selected + label
 
             if new_label in self.data_collection:
                 # Spectrum with these converted units already exists.
