@@ -13,9 +13,9 @@ from matplotlib.colors import cnames
 from astropy import units as u
 
 
-from jdaviz.core.events import SpectralMarksChangedMessage
+from jdaviz.core.events import SpectralMarksChangedMessage, LineIdentifyMessage
 from jdaviz.core.registries import viewer_registry
-from jdaviz.core.marks import SpectralLine, LineUncertainties, ScatterMask
+from jdaviz.core.marks import SpectralLine, LineUncertainties, ScatterMask, OffscreenLinesMarks
 from jdaviz.core.linelists import load_preset_linelist, get_available_linelists
 from jdaviz.core.freezable_state import FreezableProfileViewerState
 from jdaviz.configs.default.plugins.viewers import JdavizViewerMixin
@@ -53,6 +53,8 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._initialize_toolbar_nested(default_tool_priority=['jdaviz:selectslice'])
+        self._offscreen_lines_marks = OffscreenLinesMarks(self)
+        self.figure.marks = self.figure.marks + self._offscreen_lines_marks.marks
 
         self.display_uncertainties = False
         self.display_mask = False
@@ -206,6 +208,11 @@ class SpecvizProfileView(BqplotProfileView, JdavizViewerMixin):
         msg = SpectralMarksChangedMessage(marks, sender=self)
         self.session.hub.broadcast(msg)
 
+        if not np.any([mark.identify for mark in marks]):
+            # then clear the identified entry
+            msg = LineIdentifyMessage(name_rest='', sender=self)
+            self.session.hub.broadcast(msg)
+
     def erase_spectral_lines(self, name=None, name_rest=None, show_none=True):
         """
         Erase either all spectral lines, all spectral lines sharing the same
