@@ -132,12 +132,25 @@ class BasePluginComponent(HubListener):
             new_order = [handler] + [other for other in existing_callbacks if other != handler]
             self._plugin._trait_notifiers[traitlet_name]['change'] = new_order
 
+    @property
+    def plugin(self):
+        """
+        Access the parent plugin object
+        """
+        return self._plugin
+
     @property
     def app(self):
+        """
+        Access the parent app object
+        """
         return self._plugin.app
 
     @property
     def hub(self):
+        """
+        Access the hub attached to the parent plugin object
+        """
         return self._plugin.hub
 
     @property
@@ -201,6 +214,10 @@ class BaseSelectPluginComponent(BasePluginComponent, HasTraits):
         self.add_observe(kwargs.get('selected'), self._selected_changed, first=True)
         self.filters = filters
 
+    @property
+    def default_text(self):
+        return self._default_text
+
     @property
     def manual_options(self):
         return self._manual_options
@@ -390,7 +407,6 @@ class SubsetSelect(BaseSelectPluginComponent):
     @staticmethod
     def _subset_type(subset):
         if isinstance(subset.subset_state, RoiSubsetState):
-            # then this is a spatial subset, we want to ignore
             return 'spatial'
         else:
             return 'spectral'
@@ -427,7 +443,8 @@ class SubsetSelect(BaseSelectPluginComponent):
                 # NOTE: += will not trigger traitlet update
                 self.items = self.items + [self._subset_to_dict(subset)]  # noqa
         else:
-            if attribute in ('style'):
+            # 'type' can be passed manually rather than coming from SubsetUpdateMessage.attribute
+            if attribute in ('style', 'type'):
                 # TODO: may need to add label and then rebuild the entire list if/when
                 # we add support for renaming subsets
 
@@ -737,6 +754,7 @@ class DatasetSelect(BaseSelectPluginComponent):
         # Add/Remove Data are triggered when checked/unchecked from viewers
         self.hub.subscribe(self, AddDataMessage, handler=self._on_data_changed)
         self.hub.subscribe(self, RemoveDataMessage, handler=self._on_data_changed)
+        self.hub.subscribe(self, DataCollectionDeleteMessage, handler=self._on_data_changed)
 
         # initialize items from original viewers
         self._on_data_changed()
@@ -1024,6 +1042,8 @@ class AddResults(BasePluginComponent):
         if self.label_invalid_msg:
             raise ValueError(self.label_invalid_msg)
         data_item.meta['Plugin'] = self._plugin.__class__.__name__
+        if self.app.config == 'mosviz':
+            data_item.meta['mosviz_row'] = self.app.state.settings['mosviz_row']
 
         replace = self.viewer.selected_reference != 'spectrum-viewer'
 
