@@ -1,12 +1,18 @@
+import os
 import time
 import threading
 from collections import deque
-import os
+
+from astropy.io import fits
 from ipyvue import watch
 
 
 __all__ = []
 
+# For Metadata Viewer plugin internal use only.
+PRIHDR_KEY = '_primary_header'
+COMMENTCARD_KEY = '_fits_comment_card'
+
 
 class SnackbarQueue:
     '''
@@ -114,3 +120,37 @@ def enable_hot_reloading():
         print((
             'Watchdog module, needed for hot reloading, not found.'
             ' Please install with `pip install watchdog`'))
+
+
+def bqplot_clear_figure(fig):
+    """Clears a given ``bqplot.Figure`` to mimic matplotlib ``clf()``.
+    This is necessary when we draw multiple plots across different plugins.
+    """
+    # Clear bqplot figure (copied from bqplot/pyplot.py)
+    fig.marks = []
+    fig.axes = []
+    setattr(fig, 'axis_registry', {})
+
+
+def standardize_metadata(metadata):
+    """Standardize given metadata so it can be viewed in
+    Metadata Viewer plugin. The input can be plain
+    dictionary or FITS header object. Output is just a plain
+    dictionary.
+    """
+    if isinstance(metadata, fits.Header):
+        try:
+            out_meta = dict(metadata)
+            out_meta[COMMENTCARD_KEY] = metadata.comments
+        except Exception:  # Invalid FITS header  # pragma: no cover
+            out_meta = {}
+    elif isinstance(metadata, dict):
+        out_meta = metadata.copy()
+        # specutils nests it but we do not want nesting
+        if 'header' in metadata and isinstance(metadata['header'], fits.Header):
+            out_meta.update(standardize_metadata(metadata['header']))
+            del out_meta['header']
+    else:
+        raise TypeError('metadata must be dictionary or FITS header')
+
+    return out_meta
